==> pympdtouchgui-0.328.tgz: pympdtouchgui-0.328/libpympdtouchgui/albumart.py <==
#
# coding=utf-8
#*********************************************************************
#
# PyMPDTouchGui
# Gui for controlling the MusicPlayDaemon on Touchscreens
#
# written by Timo Boettcher
# pympdtouchgui (near) spida (.) net
#
# (C) 2007-2010 Timo Boettcher
# This is free software. You may redistribute copies of it under the
# terms of the GNU General Public License (Version 2)
# <http://www.gnu.org/licenses/gpl.html>.
# There is NO WARRANTY, to the extent permitted by law.
#
#*********************************************************************


try:
	import sys
	import logging
	import urllib, urllib2
except ImportError, err:
	print "couldn't load module. %s"%(err)
	sys.exit(2)


#==============================================================================
class albumart:
	AmazonID = ""
	def __init__(self, AmazonID):
		self.logger = logging.getLogger('pympdtouchgui')
		self.AmazonID = AmazonID

	def GetAlbumArt(self, artist, album, dest_filename):
		# Due to a bug in urllib, utf8 has to be encoded
		# http://mail.python.org/pipermail/python-dev/2006-July/067248.html
		artist = urllib.quote(artist.encode('utf-8'))
		album = urllib.quote(album.encode('utf-8'))

		search_urls = []
		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&Artist=" + artist + "&ResponseGroup=Images&Keywords=" + album,"Artist and Album"))
#		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&Artist=" + artist + "&ResponseGroup=Images","Artist"))
#		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&ResponseGroup=Images&Keywords=" + album,"Album"))

		search_strings = []
		search_strings.append(("<LargeImage><URL>http://","Large"))
		search_strings.append(("<MediunImage><URL>http://","Medium"))
		search_strings.append(("<URL>http://","Normal"))

		asin = ""
		img_url = ""
		imgfound = False
		for search_url in search_urls:
			try:
				request = urllib2.Request(search_url[0])
				opener = urllib2.build_opener()
				response = opener.open(request).read()
				start_pos = response.find("</HTTPHeaders>", 1)+13
				max_pos = response.find("<ImageSets>", start_pos)
				if response.find("<Error") > 0:
					return ""
				else:
					for search_string in search_strings:
						url_start = response.find(search_string[0], start_pos)+len(search_string[0])-len("http://")
						url_end = response.find("</URL>", url_start)
						if url_start < max_pos:
							img_url = response[url_start:url_end]
							if len(img_url)>0:
								asin_start = response.find("<ASIN>", start_pos)+len("<ASIN>")
								asin_end = response.find("</ASIN>", asin_start)
								if url_start < max_pos:
									asin = response[asin_start:asin_end]
									break


			except:
				self.logger.warn("Error fetching Albumart from Amazon")
			try:
				if len(img_url)>0:
					urllib.urlretrieve(img_url, dest_filename)
					imgfound = True
			except IOError, (errno, strerror):
				self.logger.warn("Write to %s: %s"%(dest_filename,strerror))
		return (imgfound,asin)

==> pympdtouchgui-0.429.tgz: pympdtouchgui-0.429/libpympdtouchgui/albumart.py <==
#
# coding=utf-8
#*********************************************************************
#
# PyMPDTouchGui
# Gui for controlling the MusicPlayDaemon on Touchscreens
#
# written by Timo Boettcher
# pympdtouchgui (near) spida (.) net
#
# (C) 2007-2022 Timo Boettcher
# This is free software. You may redistribute copies of it under the
# terms of the GNU General Public License (Version 2)
# <http://www.gnu.org/licenses/gpl.html>.
# There is NO WARRANTY, to the extent permitted by law.
#
#*********************************************************************


try:
	import sys
	import logging
	import urllib.request, urllib.parse, urllib.error, urllib.request, urllib.error, urllib.parse
except ImportError as err:
	print("couldn't load module. %s"%(err))
	sys.exit(2)


#==============================================================================
class albumart:
	AmazonID = ""
	def __init__(self, AmazonID):
		self.logger = logging.getLogger('pympdtouchgui')
		self.AmazonID = AmazonID

	def GetAlbumArt(self, artist, album, dest_filename):
		# Due to a bug in urllib, utf8 has to be encoded
		# http://mail.python.org/pipermail/python-dev/2006-July/067248.html
		artist = urllib.parse.quote(artist.encode('utf-8'))
		album = urllib.parse.quote(album.encode('utf-8'))

		search_urls = []
		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&Artist=" + artist + "&ResponseGroup=Images&Keywords=" + album,"Artist and Album"))
#		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&Artist=" + artist + "&ResponseGroup=Images","Artist"))
#		search_urls.append(("http://webservices.amazon.com/onca/xml?Service=AWSECommerceService&AWSAccessKeyId=" + self.AmazonID + "&Operation=ItemSearch&SearchIndex=Music&ResponseGroup=Images&Keywords=" + album,"Album"))

		search_strings = []
		search_strings.append(("<LargeImage><URL>http://", "Large"))
		search_strings.append(("<MediunImage><URL>http://", "Medium"))
		search_strings.append(("<URL>http://", "Normal"))

		asin = ""
		img_url = ""
		imgfound = False
		for search_url in search_urls:
			try:
				request = urllib.request.Request(search_url[0])
				opener = urllib.request.build_opener()
				response = opener.open(request).read()
				start_pos = response.find("</HTTPHeaders>", 1)+13
				max_pos = response.find("<ImageSets>", start_pos)
				if response.find("<Error") > 0:
					return ""
				else:
					for search_string in search_strings:
						url_start = response.find(search_string[0], start_pos)+len(search_string[0])-len("http://")
						url_end = response.find("</URL>", url_start)
						if url_start < max_pos:
							img_url = response[url_start:url_end]
							if len(img_url)>0:
								asin_start = response.find("<ASIN>", start_pos)+len("<ASIN>")
								asin_end = response.find("</ASIN>", asin_start)
								if url_start < max_pos:
									asin = response[asin_start:asin_end]
									break


			except:
				self.logger.warn("Error fetching Albumart from Amazon")
			try:
				if len(img_url)>0:
					urllib.request.urlretrieve(img_url, dest_filename)
					imgfound = True
			except IOError as xxx_todo_changeme:
				(errno, strerror) = xxx_todo_changeme.args
				self.logger.warn("Write to %s: %s"%(dest_filename, strerror))
		return (imgfound, asin)
